@@ -4,6 +4,10 @@ class InfoSystemException(Exception):
     status = 500
     message = ''
 
+    def __init__(self, message=None):
+        if message is not None:
+            self.message = message
+
 
 class NotFound(InfoSystemException):
 
@@ -16,10 +20,6 @@ class DuplicatedEntity(InfoSystemException):
     status = 404
     message = 'Entity already exists'
 
-    def __init__(self, message=None):
-        if message is not None:
-            self.message += message
-
 
 class BadRequest(InfoSystemException):
 
